@@ -3,7 +3,7 @@ __all__ = ["ArangoClient"]
 from json import dumps, loads
 from typing import Any, Callable, Optional, Sequence, Union
 
-from pkg_resources import get_distribution
+import importlib_metadata
 
 from arango.connection import (
     BasicConnection,
@@ -13,7 +13,7 @@ from arango.connection import (
 )
 from arango.database import StandardDatabase
 from arango.exceptions import ServerConnectionError
-from arango.http import DefaultHTTPClient, HTTPClient
+from arango.http import DEFAULT_REQUEST_TIMEOUT, DefaultHTTPClient, HTTPClient
 from arango.resolver import (
     HostResolver,
     RandomHostResolver,
@@ -22,6 +22,30 @@ from arango.resolver import (
 )
 
 
+def default_serializer(x: Any) -> str:
+    """
+    Default JSON serializer
+
+    :param x: A JSON data type object to serialize
+    :type x: Any
+    :return: The object serialized as a JSON string
+    :rtype: str
+    """
+    return dumps(x)
+
+
+def default_deserializer(x: str) -> Any:
+    """
+    Default JSON de-serializer
+
+    :param x: A JSON string to deserialize
+    :type x: str
+    :return: The de-serialized JSON object
+    :rtype: Any
+    """
+    return loads(x)
+
+
 class ArangoClient:
     """ArangoDB client.
 
@@ -55,10 +79,10 @@ class ArangoClient:
     :type verify_override: Union[bool, str, None]
     :param request_timeout: This is the default request timeout (in seconds)
        for http requests issued by the client if the parameter http_client is
-       not secified. The default value is 60.
+       not specified. The default value is 60.
        None: No timeout.
        int: Timeout value in seconds.
-    :type request_timeout: Any
+    :type request_timeout: int | float
     """
 
     def __init__(
@@ -67,10 +91,10 @@ class ArangoClient:
         host_resolver: str = "roundrobin",
         resolver_max_tries: Optional[int] = None,
         http_client: Optional[HTTPClient] = None,
-        serializer: Callable[..., str] = lambda x: dumps(x),
-        deserializer: Callable[[str], Any] = lambda x: loads(x),
+        serializer: Callable[..., str] = default_serializer,
+        deserializer: Callable[[str], Any] = default_deserializer,
         verify_override: Union[bool, str, None] = None,
-        request_timeout: Any = 60,
+        request_timeout: Union[int, float, None] = DEFAULT_REQUEST_TIMEOUT,
     ) -> None:
         if isinstance(hosts, str):
             self._hosts = [host.strip("/") for host in hosts.split(",")]
@@ -88,11 +112,7 @@ class ArangoClient:
             self._host_resolver = RoundRobinHostResolver(host_count, resolver_max_tries)
 
         # Initializes the http client
-        self._http = http_client or DefaultHTTPClient()
-        # Sets the request timeout.
-        # This call can only happen AFTER initializing the http client.
-        if http_client is None:
-            self.request_timeout = request_timeout
+        self._http = http_client or DefaultHTTPClient(request_timeout=request_timeout)
 
         self._serializer = serializer
         self._deserializer = deserializer
@@ -127,7 +147,7 @@ class ArangoClient:
         :return: Client version.
         :rtype: str
         """
-        version: str = get_distribution("python-arango").version
+        version: str = importlib_metadata.version("python-arango")
         return version
 
     @property
@@ -137,12 +157,12 @@ class ArangoClient:
         :return: Request timeout.
         :rtype: Any
         """
-        return self._http.REQUEST_TIMEOUT  # type: ignore
+        return self._http.request_timeout  # type: ignore
 
     # Setter for request_timeout
     @request_timeout.setter
     def request_timeout(self, value: Any) -> None:
-        self._http.REQUEST_TIMEOUT = value  # type: ignore
+        self._http.request_timeout = value  # type: ignore
 
     def db(
         self,
